pub struct BvToml {
pub project: ProjectMeta,
pub registry: Option<RegistryConfig>,
pub tools: Vec<ToolDeclaration>,
pub data: HashMap<String, DataDeclaration>,
pub hardware: HardwareProfile,
pub runtime: RuntimeConfig,
pub binary_overrides: HashMap<String, String>,
}Expand description
Contents of bv.toml.
Fields
project: ProjectMetaregistry: Option<RegistryConfig>tools: Vec<ToolDeclaration>data: HashMap<String, DataDeclaration>hardware: HardwareProfileruntime: RuntimeConfigbinary_overrides: HashMap<String, String>Resolves collisions when two tools expose the same binary name. Maps binary name to the tool id that should own the shim.
Implementations